##  Insights from Reports
Using reports, you can gain valuable insights into how applications, business capabilities, and processes support each other. This helps you drive more accurate architecture analysis based on process insights and validate to-be architecture based on process definition. Here are a few examples:
  * Using the application landscape report, you can identify which applications are part of specific processes. To do this, cluster the report by business context in the application landscape report. The landscape report displays relations based on the process hierarchy relation settings of the Signavio integration. When the M:N business context relation is selected for process hierarchy synchronization, all relations are considered, and all reused sub-processes are shown in the report. For example, in the illustration below, the sub-process ‘Check Invoice' is reused as part of both parent processes, ‘Invoice to Pay’ and 'Procure to Receipt’. To learn more about process hierarchy relations, see [Choosing Process Hierarchy Relation](https://help.sap.com/docs/leanix/ea/mapping-sap-signavio-processes-to-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio275c6bbc7a441014a433b40fb48bd4d6__choosing_process_hierarchy_relation).
![Application Landscape Report Clustered by Process](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2744fe5b7a441014bd1abc527cad8b3d_LowRes.png)
Application Landscape Report Clustered by Process
This provides insights for both Enterprise Architectures (EA) and Business Process Managers (BPM) by showing how processes depend on applications and vice versa. It helps in proactively managing lifecycle implications and other changes effectively.
  * Applying the lifecycle view allows you to quickly identify candidates approaching end-of-life, helping you prioritize the need for successors.
  * Applying the TIME assessment as a view helps you identify applications that need to be eliminated or migrated to better support or improve the process. To learn more about TIME assessment, see [Gartner® TIME Framework](https://help.sap.com/docs/leanix/ea/time?locale=en-US&state=PRODUCTION&version=CLOUD).
  * The data landscape report, clustered by processes, helps BPM and EA practitioners understand which critical data are processed along certain processes, enabling them to manage data privacy and compliance.
  * Using the business capability landscape report clustered by process and applying the process maturity view helps examine the maturity levels of the underlying processes. This allows you to infer the maturity of the corresponding business capabilities or identify which business capabilities are supported by processes with low maturity.
  * You can use a process landscape report to visualize the process hierarchy and get an overview of which sub-processes belong to a parent process. This helps you harmonize architecture initiatives by mapping dependent processes early on.
